import numpy as np


def calculate_no_of_panels(system_size, panel_peak_power):
    """
    Calculate the number of panels needed for a given system size and panel peak power.

    Args:
        system_size (float): The total system size in kWp.
        panel_peak_power (float): The peak power of a single panel in Wp.

    Returns:
        int: The number of panels needed.
    """
    panel_peak_power_kWp = panel_peak_power / 1000  # Convert Wp to kWp
    no_of_panels = np.ceil(system_size / panel_peak_power_kWp)

    return no_of_panels


def calculate_required_system_size(c):
    c["array"]["system_size"] = (
        c["array"]["peak_power_demand"]
        * c["array"]["DC_AC_ratio"]
        * c["array"]["performance_ratio"]
    )

    return c
